import React, { Component, useState, useEffect } from 'react';
import { Card,Table,Button } from 'antd';
import EChart from '../../../../components/EchartsTest/EChart';
import request from '../../../../utils/request';
import apis from '../../../../services/apis';
import moment from 'moment';
import router from 'umi/router';
import Navigate from '@/components/Navigate';
import AuthButton from '@/components/AuthButton';
const ContentTable = props => {
  const { params } = props;
  const [data, setData] = useState({ records: [] });
  const formatDate = (start, end) => {
    const startDate = moment(start).format('YYYY-MM-DDT00:00:00.000') + 'Z';
    const endDate = moment(end).format('YYYY-MM-DDT23:59:59.999') + 'Z';
    return { startDate, endDate };
  };

  useEffect(() => {
    getTableList({
      ...params,
    });
  }, [params]);

  function getTableList(params) {
    request({
      ...apis.activityDataStatis.activityDetailTableData,
      params: {
        ...params,
      },
    })
      .then(data => {
        console.log(data);
        setData(data);
        // this.setState({ tableData: data.records, total: data.total });
      })
      .catch();
  }
  const columns = [
    {
      title: '活动名称',
      dataIndex: 'title',
      key: 'title',
      // sorter: true,
    },
    {
      title: '访问人数',
      dataIndex: 'visitPersonNum',
      key: 'visit_person_num',
      width: '25%',
      sorter: true,
      render: text => text || 0,
    },
    {
      title: '访问次数',
      dataIndex: 'visitNum',
      key: 'visit_num',
      width: '25%',
      sorter: true,
      render: text => text || 0,
    },
    {
      title: '报名人数',
      dataIndex: 'signNum',
      key: 'sign_num',
      width: '25%',
      sorter: true,
      // render: (text)=>text||0
      render: (text, record) =>
        text ? <Navigate onClick={() => toAddVisitNum(record)}>{record.signNum}</Navigate> : 0,
      // <a style={{ color: '#66B3FF' }} onClick={toAddVisitNum(record)}><span>{record.visitNum}</span></a>
    },
  ];

  const toAddVisitNum = record => {
    router.push({
      pathname: '/activity/SignupActivity/registrationRecord',
      query: {
        dynamicId: record.dynamicId,
      },
    });
  };

  //排序
  const handleTableChange = (pagination, filters, sorter) => {
    console.log(pagination, filters, sorter);
    // Desc  和asc
    const sortType =
      sorter.order == 'ascend' ? 'asc' : sorter.order == 'descend' ? 'Desc' : undefined;
    getTableList({
      ...params,
      pageNum: pagination.current,
      pageSize: pagination.pageSize,
      sortType: sortType,
      sortField: sorter.columnKey,
    });
  };

 const exportActivityStats = () => {

    request({ ...apis.activityDataStatis.activityDetailTableDataExport, params: params }).then(data => {
      if (!data) {
        return
      }
      const url = window.URL.createObjectURL(new Blob([data]))
      const link = document.createElement('a')
      link.style.display = 'none'
      link.href = url
      link.setAttribute('download', '活动统计.xlsx')
      document.body.append(link)
      link.click()
    }).catch()
  }
  return (
    <Card>
        <div style={{textAlign:'right'}}> 
        <AuthButton name="admin.statistical.activity.export" noRight={null}>
              <Button type="primary" style={{ float: 'right', margin: '20px 0', zIndex: 1 }} onClick={exportActivityStats}>
                导出
            </Button>
            </AuthButton>
        </div>
        
      <Table
        columns={columns}
        dataSource={data?.records}
        key="dynamicId"
        pagination={{ current: data?.current, pageSize: 10, total: data?.total }}
        onChange={handleTableChange}
      ></Table>
    </Card>
    // <>
    //   <div ><p><span style={{fontSize:'0.12rem',fontWeight:'600'}}>活动趋势图</span></p></div>
    //   <div style={{marginTop:'30px'}}>

    //   </div>
    // </>
  );
};

export default ContentTable;
